@@ -285,6 +285,7 @@ where
                             ..opts
                         },
                     );
+                    let span = bin.span;
 
                     if bin.left.is_invalid() && bin.right.is_invalid() {
                         *e = Expr::Invalid(Invalid { span: DUMMY_SP });
@@ -296,6 +297,16 @@ where
                         *e = *bin.right.take();
                         return;
                     }
+
+                    if bin.left.is_await_expr() {
+                        self.changed = true;
+                        tracing::debug!("ignore_return_value: Left is await");
+                        *e = Expr::Seq(SeqExpr {
+                            span,
+                            exprs: vec![bin.left.take(), bin.right.take()],
+                        });
+                        return;
+                    }
                 }
 
                 Expr::Assign(assign @ AssignExpr { op: op!("="), .. }) => {
